/*====================================+=====================================+
! File CPlSubWin.h                    ! Copyright (C) 2016-2019 Remi PASCAL !
+-------------------------------------+-------------------------------------+
! This file is part of matelefree.                                          !
! matelefree is free software: you can redistribute it and/or modify it     !
! under the terms of the GNU General Public License as published by the     !
! Free Software Foundation, either version 3 of the License, or any later   !
! version.                                                                  !
! matelefree is distributed in the hope that it will be useful, but WITHOUT !
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or     !
! FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for !
! more details.                                                             !
! You should have received a copy of the GNU General Public License along   !
! with matelefree. If not, see <http://www.gnu.org/licenses/>.              !
+==========================================================================*/



/*-------------------------------------------------------------------------*/
#pragma once
/*-------------------------------------------------------------------------*/
#include <wx/wx.h>
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
class CPlSubWin : public wxPanel
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPlSubWin( wxWindow *parent, CPlaylist *pl ) ;
      //~CPlSubWin() ;

   /*----------------------------------------------------------------------*/
   protected :
      /*-------------------------------------------------------------------*/
      CPlaylist    *m_pl          = nullptr ;
      wxBoxSizer   *m_bsz         = nullptr ;
      wxButton     *m_bt_start    = nullptr ;
      wxGauge      *m_ga_progress = nullptr ;
      wxStaticText *m_stx_msg     = nullptr ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPlaylist *get_pl() const { return( m_pl ) ; }
      void enable_start( bool boo_on ) { m_bt_start->Enable( boo_on ) ; }
      /*-------------------------------------------------------------------*/
      void reset_gui_search() ;
      void show_info() ;
      void msg_info( const wxString &s ) ;
      void msg_channel_found( int i_nb_found ) ;
      void msg_error( const wxString &s ) ;
      virtual void start() = 0 ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CPlSubWinFbtvoOk : public CPlSubWin
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPlSubWinFbtvoOk( wxWindow *parent, CPlaylist *pl_fbtvo_ok ) ;
      //~CPlSubWinFbtvoOk() ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      virtual void start() ;

   /*----------------------------------------------------------------------*/
} ;


/*-------------------------------------------------------------------------*/
wxDECLARE_EVENT( EVT_COA_END,  CEvent ) ;
class CCOAInfoEvent ;
wxDECLARE_EVENT( EVT_COA_INFO, CCOAInfoEvent ) ;

/*--( Channel On Air Info event )------------------------------------------*/
class CCOAInfoEvent : public wxEvent
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CCOAInfoEvent( int i_item, int i_nb_found )
                   : wxEvent( 0, EVT_COA_INFO ),
                     m_i_item( i_item ), m_i_nb_found( i_nb_found )
      {  ; }

   /*----------------------------------------------------------------------*/
   private :
      /*-------------------------------------------------------------------*/
      int m_i_item ;
      int m_i_nb_found ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      virtual wxEvent *Clone() const override
      {  return new CCOAInfoEvent( *this ) ; }
      /*-------------------------------------------------------------------*/
      int get_item() const { return( m_i_item ) ; }
      int get_nb_found() const { return( m_i_nb_found ) ; }

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CPlSubWinChOnair : public CPlSubWin
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPlSubWinChOnair( wxWindow *parent, CPlaylist *pl_live,
                        CPlSubWinLive *subwinlive = nullptr
                      ) ;
      //~CPlSubWinChOnair() ;

   /*----------------------------------------------------------------------*/
   private :
      /*-------------------------------------------------------------------*/
      CPlSubWinLive *m_subwinlive = nullptr ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPlSubWinLive *get_subwinlive() const
      {  return( m_subwinlive ) ; }
      /*-------------------------------------------------------------------*/
      virtual void start() ;
      void run_info( int i_pos, int i_nb_found ) ;
      void finish() ;

   /*----------------------------------------------------------------------*/
} ;



/*-------------------------------------------------------------------------*/
class CPlSubWinLive : public wxPanel
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPlSubWinLive( wxWindow *parent, CPlaylistLive *pl_live ) ;
      //~CPlSubWinLive() ;

   /*----------------------------------------------------------------------*/
   private :
      /*-------------------------------------------------------------------*/
      CPlaylistLive    *m_pl        = nullptr ;
      /*-------------------------------------------------------------------*/
      wxBoxSizer       *m_bsz       = nullptr ;
      wxButton         *m_bt_add    = nullptr ;
      CPlSubWinChOnair *m_win_onair = nullptr ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPlaylist *get_pl() const { return( m_pl ) ; }
      wxButton *get_bt_add() const { return( m_bt_add ) ; }
      CPlSubWinChOnair *get_win_onair() const { return( m_win_onair ) ; }
      void enable_onair( bool boo_on )
      {  m_win_onair->enable_start( boo_on ) ; }
      void expand_win_onair() ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/



/*==========================================================================+
!                          End of file CPlSubWin.h                          !
+==========================================================================*/
