/*====================================+=====================================+
! File CConfig.cpp                    ! Copyright (C) 2016-2019 Remi PASCAL !
+-------------------------------------+-------------------------------------+
! This file is part of matelefree.                                          !
! matelefree is free software: you can redistribute it and/or modify it     !
! under the terms of the GNU General Public License as published by the     !
! Free Software Foundation, either version 3 of the License, or any later   !
! version.                                                                  !
! matelefree is distributed in the hope that it will be useful, but WITHOUT !
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or     !
! FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for !
! more details.                                                             !
! You should have received a copy of the GNU General Public License along   !
! with matelefree. If not, see <http://www.gnu.org/licenses/>.              !
+==========================================================================*/



/*-------------------------------------------------------------------------*/
#include <wx/fileconf.h>
#include <wx/log.h>
/*-------------------------------------------------------------------------*/
#include "matelefree.h"
#include "matelefree_info.h"
#include "CConfig.h"
#include "CApp.h"
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
void CConfig_open( const wxString &s_file, const int i_version )
{
   /*----------------------------------------------------------------------*/
   wxFileConfig *p_conf    ;
   CConfigInt   pi_version ;

   /*----------------------------------------------------------------------*/
   p_conf = new wxFileConfig( wxEmptyString, wxEmptyString, s_file,
                                wxEmptyString,
                                wxCONFIG_USE_LOCAL_FILE
                              | wxCONFIG_USE_RELATIVE_PATH
                            ) ;
   /*-----------------------------------------------------------------------+
   ! By default the strings written are analysed and the environment        !
   ! variables are replaced.                                                !
   +-----------------------------------------------------------------------*/
   p_conf->SetExpandEnvVars( false ) ;
   wxConfigBase::Set( p_conf ) ;

   /*--( Check configuration data version )--------------------------------*/
   pi_version.init( "/profile/version", -1 ) ;
   /*--( If it contains the current version, all is OK )-------------------*/
   if( pi_version.get() == i_version )
   {  return ; }

   /*--( A previous version ? Try to keep info )---------------------------*/
   if( pi_version.get() != -1 )
   {
      /*--( Make a backup of the file )------------------------------------*/
      if( !wxCopyFile( s_file, s_file + ".bak" ) )
      {  return ; }

      /*--( Keep language and playlists if present before reset )----------*/
      wxGetApp().init_config_info_to_keep() ;

      /*--------------------------------------------------------------------+
      ! The config file is here but with a "wrong" version value.           !
      ! It has to be "cleaned".                                             !
      +--------------------------------------------------------------------*/
      wxString s_group ;
      long     l_index ;

      /*--( Reset file content after copy keeping some groups )------------*/
      if( p_conf->GetFirstGroup( s_group, l_index ) )
      {
         /*----------------------------------------------------------------*/
         do
         {  /*--( Delete the groups that have not to be kept )-------------*/
            if( s_group != "playlist" ) { p_conf->DeleteGroup( s_group ) ; }
            /*-------------------------------------------------------------*/
         } while( p_conf->GetNextGroup( s_group, l_index ) ) ;
         /*----------------------------------------------------------------*/
      }

      /*--( The variables have to be written before being "reloaded" )-----*/
      wxGetApp().M_s_lang.write_val() ;
      wxGetApp().M_s_bopl_pl_user_list.write_val() ;

      /*-------------------------------------------------------------------*/
      wxGetApp().init_translations( wxGetApp().M_s_lang.get() ) ;

      /*-------------------------------------------------------------------*/
      wxString s_name = MTF_DISPLAY_NAME ;
      wxMessageBox( wxString::Format(
                    _( "The configuration file doesn't correspond to the "
                       "current version of %s.\n"
                       "It has been reinitialized (after a backup copy).\n"
                       "Only the users playlists have been kept."
                      ),
                    s_name
                                    ), s_name

                  ) ;
      /*-------------------------------------------------------------------*/
   }

   /*--( Write new current version value )---------------------------------*/
   pi_version.set( i_version ) ;
   pi_version.write_val() ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/



/*==========================================================================+
!                            End of file CConfig.cpp                        !
+==========================================================================*/
